/**
 * 数据字典工具类
 */
import { useDictStoreWithOut } from '@/store/modules/dict'
import type { StringLiteralsToType } from '@/types/utils'

const dictStore = useDictStoreWithOut()

/**
 * 获取 dictType 对应的数据字典数组
 *
 * @param dictType 数据类型
 * @returns {*|Array} 数据字典数组
 */
export interface DictDataType<T extends string | number | boolean = string> {
  dictType: string
  label: string
  value: T
  key?: any
  colorType: string
  cssClass: string
}

export function getDictDatas(dictType: string) {
  return dictStore.getDictMap[dictType] || []
}

export function getDictOpts(dictType: string) {
  /**
   * 这里原来是转换类型  转换类型后反而显示不出来正确的Tag
   * 实际类型转换交给下面的getDictOptions来处理
   *
   * bugfix:
   * dictOption.push({
          ...dict,
          value: parseInt(dict.value + '')
        })
     原来的这种写法是造成页面卡死的原因
   */
  return getDictDatas(dictType)
}

export function getDictOptions<T extends 'string' | 'number' | 'boolean' = 'string'>(dictType: string, valueType?: T) {
  const dictOption: DictDataType<StringLiteralsToType<T>>[] = []
  const dictOptions: DictDataType[] = getDictDatas(dictType)
  if (dictOptions && dictOptions.length > 0) {
    dictOptions.forEach((dict: DictDataType) => {
      dictOption.push({
        ...dict,
        key: dict.value,
        value:
          valueType === 'string'
            ? `${dict.value}`
            : valueType === 'boolean'
              ? `${dict.value}` === 'true'
              : Number.parseInt(`${dict.value}`),
      } as DictDataType<StringLiteralsToType<T>>)
    })
  }
  return dictOption
}

export function getDictObj(dictType: string, value: any) {
  const dictOptions: DictDataType[] = getDictDatas(dictType)
  if (dictOptions) {
    dictOptions.forEach((dict: DictDataType) => {
      if (dict.value === value.toString())
        return dict
    })
  }
  else {
    return null
  }
}

export enum DICT_TYPE {
  USER_TYPE = 'user_type',
  COMMON_STATUS = 'common_status',
  SYSTEM_TENANT_PACKAGE_ID = 'system_tenant_package_id',
  SYSTEM_USER_SEX = 'system_user_sex',
  SYSTEM_MENU_TYPE = 'system_menu_type',
  SYSTEM_ROLE_TYPE = 'system_role_type',
  SYSTEM_DATA_SCOPE = 'system_data_scope',
  SYSTEM_NOTICE_TYPE = 'system_notice_type',
  SYSTEM_OPERATE_TYPE = 'system_operate_type',
  SYSTEM_LOGIN_TYPE = 'system_login_type',
  SYSTEM_LOGIN_RESULT = 'system_login_result',
  SYSTEM_SMS_CHANNEL_CODE = 'system_sms_channel_code',
  SYSTEM_SMS_TEMPLATE_TYPE = 'system_sms_template_type',
  SYSTEM_SMS_SEND_STATUS = 'system_sms_send_status',
  SYSTEM_SMS_RECEIVE_STATUS = 'system_sms_receive_status',
  SYSTEM_ERROR_CODE_TYPE = 'system_error_code_type',
  SYSTEM_OAUTH2_GRANT_TYPE = 'system_oauth2_grant_type',
  SYSTEM_MAIL_SEND_STATUS = 'system_mail_send_status',
  SYSTEM_NOTIFY_TEMPLATE_TYPE = 'system_notify_template_type',
  INFRA_BOOLEAN_STRING = 'infra_boolean_string',
}
